# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# Fleet Commander

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ApiFleetClaimResponse(Model):
    """Api fleet claim response (api.FleetClaimResponse)

    Properties:
        ip: (ip) REQUIRED str

        ports: (ports) REQUIRED Dict[str, int]

        region: (region) REQUIRED str

        server_id: (serverId) REQUIRED str
    """

    # region fields

    ip: str  # REQUIRED
    ports: Dict[str, int]  # REQUIRED
    region: str  # REQUIRED
    server_id: str  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_ip(self, value: str) -> ApiFleetClaimResponse:
        self.ip = value
        return self

    def with_ports(self, value: Dict[str, int]) -> ApiFleetClaimResponse:
        self.ports = value
        return self

    def with_region(self, value: str) -> ApiFleetClaimResponse:
        self.region = value
        return self

    def with_server_id(self, value: str) -> ApiFleetClaimResponse:
        self.server_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "ip"):
            result["ip"] = str(self.ip)
        elif include_empty:
            result["ip"] = ""
        if hasattr(self, "ports"):
            result["ports"] = {str(k0): int(v0) for k0, v0 in self.ports.items()}
        elif include_empty:
            result["ports"] = {}
        if hasattr(self, "region"):
            result["region"] = str(self.region)
        elif include_empty:
            result["region"] = ""
        if hasattr(self, "server_id"):
            result["serverId"] = str(self.server_id)
        elif include_empty:
            result["serverId"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls, ip: str, ports: Dict[str, int], region: str, server_id: str, **kwargs
    ) -> ApiFleetClaimResponse:
        instance = cls()
        instance.ip = ip
        instance.ports = ports
        instance.region = region
        instance.server_id = server_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApiFleetClaimResponse:
        instance = cls()
        if not dict_:
            return instance
        if "ip" in dict_ and dict_["ip"] is not None:
            instance.ip = str(dict_["ip"])
        elif include_empty:
            instance.ip = ""
        if "ports" in dict_ and dict_["ports"] is not None:
            instance.ports = {str(k0): int(v0) for k0, v0 in dict_["ports"].items()}
        elif include_empty:
            instance.ports = {}
        if "region" in dict_ and dict_["region"] is not None:
            instance.region = str(dict_["region"])
        elif include_empty:
            instance.region = ""
        if "serverId" in dict_ and dict_["serverId"] is not None:
            instance.server_id = str(dict_["serverId"])
        elif include_empty:
            instance.server_id = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApiFleetClaimResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApiFleetClaimResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApiFleetClaimResponse,
        List[ApiFleetClaimResponse],
        Dict[Any, ApiFleetClaimResponse],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "ip": "ip",
            "ports": "ports",
            "region": "region",
            "serverId": "server_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "ip": True,
            "ports": True,
            "region": True,
            "serverId": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelsArchiveLeaderboardReq
from ..models import ModelsArchiveLeaderboardSignedURLResponse
from ..models import ModelsGetLeaderboardRankingResp
from ..models import ModelsUpdateUserPointAdminV1Request
from ..models import ModelsUpdateUserPointAdminV1Response
from ..models import ModelsUserRankingResponse
from ..models import ResponseErrorResponse
from ..models import V2GetPublicLeaderboardRankingResponse

from ..operations.leaderboard_data import (
    AdminGetArchivedLeaderboardRankingDataV1Handler,
)
from ..operations.leaderboard_data import CreateArchivedLeaderboardRankingDataV1Handler
from ..operations.leaderboard_data import DeleteUserRankingAdminV1
from ..operations.leaderboard_data import DeleteUserRankingByLeaderboardCodeAdminV1
from ..operations.leaderboard_data import DeleteUserRankingPublicV1
from ..operations.leaderboard_data import DeleteUserRankingsAdminV1
from ..operations.leaderboard_data import GetAllTimeLeaderboardRankingAdminV1
from ..operations.leaderboard_data import GetAllTimeLeaderboardRankingPublicV1
from ..operations.leaderboard_data import GetAllTimeLeaderboardRankingPublicV2
from ..operations.leaderboard_data import GetArchivedLeaderboardRankingDataV1Handler
from ..operations.leaderboard_data import GetCurrentMonthLeaderboardRankingAdminV1
from ..operations.leaderboard_data import GetCurrentMonthLeaderboardRankingPublicV1
from ..operations.leaderboard_data import GetCurrentSeasonLeaderboardRankingAdminV1
from ..operations.leaderboard_data import GetCurrentSeasonLeaderboardRankingPublicV1
from ..operations.leaderboard_data import GetCurrentWeekLeaderboardRankingAdminV1
from ..operations.leaderboard_data import GetCurrentWeekLeaderboardRankingPublicV1
from ..operations.leaderboard_data import GetTodayLeaderboardRankingAdminV1
from ..operations.leaderboard_data import GetTodayLeaderboardRankingPublicV1
from ..operations.leaderboard_data import GetUserRankingAdminV1
from ..operations.leaderboard_data import GetUserRankingPublicV1
from ..operations.leaderboard_data import UpdateUserPointAdminV1


@same_doc_as(AdminGetArchivedLeaderboardRankingDataV1Handler)
def admin_get_archived_leaderboard_ranking_data_v1_handler(
    leaderboard_codes: str,
    slug: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Admin Get signed url for archive all time leaderboard ranking data (AdminGetArchivedLeaderboardRankingDataV1Handler)

    Admin Get signed url in an all time leaderboard that archived. Notes: This will be a bulk endpoint to get sign url

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/archived

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        slug: (slug) OPTIONAL str in query

        leaderboard_codes: (leaderboardCodes) REQUIRED str in query

    Responses:
        200: OK - List[ModelsArchiveLeaderboardSignedURLResponse] (leaderboard archive retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error | 71239: leaderboard is not archived)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetArchivedLeaderboardRankingDataV1Handler.create(
        leaderboard_codes=leaderboard_codes,
        slug=slug,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetArchivedLeaderboardRankingDataV1Handler)
async def admin_get_archived_leaderboard_ranking_data_v1_handler_async(
    leaderboard_codes: str,
    slug: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Admin Get signed url for archive all time leaderboard ranking data (AdminGetArchivedLeaderboardRankingDataV1Handler)

    Admin Get signed url in an all time leaderboard that archived. Notes: This will be a bulk endpoint to get sign url

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/archived

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        slug: (slug) OPTIONAL str in query

        leaderboard_codes: (leaderboardCodes) REQUIRED str in query

    Responses:
        200: OK - List[ModelsArchiveLeaderboardSignedURLResponse] (leaderboard archive retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error | 71239: leaderboard is not archived)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetArchivedLeaderboardRankingDataV1Handler.create(
        leaderboard_codes=leaderboard_codes,
        slug=slug,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(CreateArchivedLeaderboardRankingDataV1Handler)
def create_archived_leaderboard_ranking_data_v1_handler(
    body: ModelsArchiveLeaderboardReq,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Archive a leadeboard data ranking (CreateArchivedLeaderboardRankingDataV1Handler)

    Archive leaderboard ranking data for specified leaderboard codes. NOTE: This will remove all data of the leaderboard on every slug,
    remove the leaderboard code on stat mapping, and remove the leaderboard on the queue reset. This will be a bulk endpoint

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/archived

        method: POST

        tags: ["LeaderboardData"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsArchiveLeaderboardReq in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        201: Created - (leaderboard data ranking archived)

        400: Bad Request - ResponseErrorResponse (20002: validation error | 20019: unable to parse request body)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = CreateArchivedLeaderboardRankingDataV1Handler.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(CreateArchivedLeaderboardRankingDataV1Handler)
async def create_archived_leaderboard_ranking_data_v1_handler_async(
    body: ModelsArchiveLeaderboardReq,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Archive a leadeboard data ranking (CreateArchivedLeaderboardRankingDataV1Handler)

    Archive leaderboard ranking data for specified leaderboard codes. NOTE: This will remove all data of the leaderboard on every slug,
    remove the leaderboard code on stat mapping, and remove the leaderboard on the queue reset. This will be a bulk endpoint

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/archived

        method: POST

        tags: ["LeaderboardData"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsArchiveLeaderboardReq in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        201: Created - (leaderboard data ranking archived)

        400: Bad Request - ResponseErrorResponse (20002: validation error | 20019: unable to parse request body)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = CreateArchivedLeaderboardRankingDataV1Handler.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteUserRankingAdminV1)
def delete_user_ranking_admin_v1(
    leaderboard_code: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete user ranking (deleteUserRankingAdminV1)

    Delete user ranking

    Remove entry with provided userId from leaderboard.
    If leaderboard with given leaderboard code not found, it will return http status not found (404).
    If the leaderboard is found and no entry found in it, it will still return success (204)

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/users/{userId}

        method: DELETE

        tags: ["LeaderboardData"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (User ranking deleted)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found | 71233: user ranking data not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteUserRankingAdminV1.create(
        leaderboard_code=leaderboard_code,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteUserRankingAdminV1)
async def delete_user_ranking_admin_v1_async(
    leaderboard_code: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete user ranking (deleteUserRankingAdminV1)

    Delete user ranking

    Remove entry with provided userId from leaderboard.
    If leaderboard with given leaderboard code not found, it will return http status not found (404).
    If the leaderboard is found and no entry found in it, it will still return success (204)

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/users/{userId}

        method: DELETE

        tags: ["LeaderboardData"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (User ranking deleted)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found | 71233: user ranking data not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteUserRankingAdminV1.create(
        leaderboard_code=leaderboard_code,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteUserRankingByLeaderboardCodeAdminV1)
def delete_user_ranking_by_leaderboard_code_admin_v1(
    leaderboard_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """delete all user ranking by leaderboard code (deleteUserRankingByLeaderboardCodeAdminV1)

    [Test Facility Only]




    This endpoint will delete user ranking by leaderboard code




    Note: this endpoint only works on development environment.

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/reset

        method: DELETE

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (Leaderboard deleted)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions | 71241: forbidden environment)

        404: Not Found - ResponseErrorResponse (71130: leaderboard config not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteUserRankingByLeaderboardCodeAdminV1.create(
        leaderboard_code=leaderboard_code,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteUserRankingByLeaderboardCodeAdminV1)
async def delete_user_ranking_by_leaderboard_code_admin_v1_async(
    leaderboard_code: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """delete all user ranking by leaderboard code (deleteUserRankingByLeaderboardCodeAdminV1)

    [Test Facility Only]




    This endpoint will delete user ranking by leaderboard code




    Note: this endpoint only works on development environment.

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/reset

        method: DELETE

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (Leaderboard deleted)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions | 71241: forbidden environment)

        404: Not Found - ResponseErrorResponse (71130: leaderboard config not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteUserRankingByLeaderboardCodeAdminV1.create(
        leaderboard_code=leaderboard_code,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteUserRankingPublicV1)
def delete_user_ranking_public_v1(
    leaderboard_code: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete user ranking (deleteUserRankingPublicV1)

    Delete user ranking

    Remove entry with provided userId from leaderboard.
    If leaderboard with given leaderboard code not found, it will return http status not found (404).
    If the leaderboard is found and no entry found in it, it will still return success (204)

    Properties:
        url: /leaderboard/v1/public/namespaces/{namespace}/leaderboards/{leaderboardCode}/users/{userId}

        method: DELETE

        tags: ["LeaderboardData"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (User ranking deleted)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found | 71233: user ranking data not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteUserRankingPublicV1.create(
        leaderboard_code=leaderboard_code,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteUserRankingPublicV1)
async def delete_user_ranking_public_v1_async(
    leaderboard_code: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete user ranking (deleteUserRankingPublicV1)

    Delete user ranking

    Remove entry with provided userId from leaderboard.
    If leaderboard with given leaderboard code not found, it will return http status not found (404).
    If the leaderboard is found and no entry found in it, it will still return success (204)

    Properties:
        url: /leaderboard/v1/public/namespaces/{namespace}/leaderboards/{leaderboardCode}/users/{userId}

        method: DELETE

        tags: ["LeaderboardData"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (User ranking deleted)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found | 71233: user ranking data not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteUserRankingPublicV1.create(
        leaderboard_code=leaderboard_code,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteUserRankingsAdminV1)
def delete_user_rankings_admin_v1(
    leaderboard_code: List[str],
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete user ranking across leaderboard(s) (deleteUserRankingsAdminV1)

    Delete user ranking across leaderboard

    Remove entry with provided userId from leaderboard.

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/users/{userId}

        method: DELETE

        tags: ["LeaderboardData"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        leaderboard_code: (leaderboardCode) REQUIRED List[str] in query

    Responses:
        204: No Content - (User ranking deleted)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteUserRankingsAdminV1.create(
        leaderboard_code=leaderboard_code,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteUserRankingsAdminV1)
async def delete_user_rankings_admin_v1_async(
    leaderboard_code: List[str],
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete user ranking across leaderboard(s) (deleteUserRankingsAdminV1)

    Delete user ranking across leaderboard

    Remove entry with provided userId from leaderboard.

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/users/{userId}

        method: DELETE

        tags: ["LeaderboardData"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        leaderboard_code: (leaderboardCode) REQUIRED List[str] in query

    Responses:
        204: No Content - (User ranking deleted)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteUserRankingsAdminV1.create(
        leaderboard_code=leaderboard_code,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetAllTimeLeaderboardRankingAdminV1)
def get_all_time_leaderboard_ranking_admin_v1(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all time leaderboard ranking data (GetAllTimeLeaderboardRankingAdminV1)

    Get rankings in an all time leaderboard.

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/alltime

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (All time leaderboard ranking data retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71130: leaderboard config not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetAllTimeLeaderboardRankingAdminV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetAllTimeLeaderboardRankingAdminV1)
async def get_all_time_leaderboard_ranking_admin_v1_async(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all time leaderboard ranking data (GetAllTimeLeaderboardRankingAdminV1)

    Get rankings in an all time leaderboard.

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/alltime

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (All time leaderboard ranking data retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71130: leaderboard config not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetAllTimeLeaderboardRankingAdminV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetAllTimeLeaderboardRankingPublicV1)
def get_all_time_leaderboard_ranking_public_v1(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all time leaderboard ranking data (GetAllTimeLeaderboardRankingPublicV1)

    Get rankings in an all time leaderboard.

    Properties:
        url: /leaderboard/v1/public/namespaces/{namespace}/leaderboards/{leaderboardCode}/alltime

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (All time leaderboard ranking data retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetAllTimeLeaderboardRankingPublicV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetAllTimeLeaderboardRankingPublicV1)
async def get_all_time_leaderboard_ranking_public_v1_async(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all time leaderboard ranking data (GetAllTimeLeaderboardRankingPublicV1)

    Get rankings in an all time leaderboard.

    Properties:
        url: /leaderboard/v1/public/namespaces/{namespace}/leaderboards/{leaderboardCode}/alltime

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (All time leaderboard ranking data retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetAllTimeLeaderboardRankingPublicV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetAllTimeLeaderboardRankingPublicV2)
def get_all_time_leaderboard_ranking_public_v2(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all time leaderboard ranking data (GetAllTimeLeaderboardRankingPublicV2)

    Get rankings in an all time leaderboard.

    Properties:
        url: /leaderboard/v2/public/namespaces/{namespace}/leaderboards/{leaderboardCode}/alltime

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - V2GetPublicLeaderboardRankingResponse (All time leaderboard ranking retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71130: leaderboard config not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetAllTimeLeaderboardRankingPublicV2.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetAllTimeLeaderboardRankingPublicV2)
async def get_all_time_leaderboard_ranking_public_v2_async(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get all time leaderboard ranking data (GetAllTimeLeaderboardRankingPublicV2)

    Get rankings in an all time leaderboard.

    Properties:
        url: /leaderboard/v2/public/namespaces/{namespace}/leaderboards/{leaderboardCode}/alltime

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - V2GetPublicLeaderboardRankingResponse (All time leaderboard ranking retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71130: leaderboard config not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetAllTimeLeaderboardRankingPublicV2.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetArchivedLeaderboardRankingDataV1Handler)
def get_archived_leaderboard_ranking_data_v1_handler(
    leaderboard_code: str,
    leaderboard_codes: str,
    slug: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get signed url for archive all time leaderboard ranking data (GetArchivedLeaderboardRankingDataV1Handler)

    Get signed url in an all time leaderboard that archived. NOTE: This will be a bulk endpoint to get sign url

    Properties:
        url: /leaderboard/v1/public/namespaces/{namespace}/leaderboards/{leaderboardCode}/archived

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        slug: (slug) OPTIONAL str in query

        leaderboard_codes: (leaderboardCodes) REQUIRED str in query

    Responses:
        200: OK - List[ModelsArchiveLeaderboardSignedURLResponse] (Archived leaderboard retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error | 71239: leaderboard is not archived)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetArchivedLeaderboardRankingDataV1Handler.create(
        leaderboard_code=leaderboard_code,
        leaderboard_codes=leaderboard_codes,
        slug=slug,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetArchivedLeaderboardRankingDataV1Handler)
async def get_archived_leaderboard_ranking_data_v1_handler_async(
    leaderboard_code: str,
    leaderboard_codes: str,
    slug: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get signed url for archive all time leaderboard ranking data (GetArchivedLeaderboardRankingDataV1Handler)

    Get signed url in an all time leaderboard that archived. NOTE: This will be a bulk endpoint to get sign url

    Properties:
        url: /leaderboard/v1/public/namespaces/{namespace}/leaderboards/{leaderboardCode}/archived

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        slug: (slug) OPTIONAL str in query

        leaderboard_codes: (leaderboardCodes) REQUIRED str in query

    Responses:
        200: OK - List[ModelsArchiveLeaderboardSignedURLResponse] (Archived leaderboard retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error | 71239: leaderboard is not archived)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetArchivedLeaderboardRankingDataV1Handler.create(
        leaderboard_code=leaderboard_code,
        leaderboard_codes=leaderboard_codes,
        slug=slug,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetCurrentMonthLeaderboardRankingAdminV1)
def get_current_month_leaderboard_ranking_admin_v1(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get current month leaderboard ranking data (GetCurrentMonthLeaderboardRankingAdminV1)

    Get rankings in current month leaderboard.

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/month

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (Current month leaderboard ranking retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71130: leaderboard config not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetCurrentMonthLeaderboardRankingAdminV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        previous_version=previous_version,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetCurrentMonthLeaderboardRankingAdminV1)
async def get_current_month_leaderboard_ranking_admin_v1_async(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get current month leaderboard ranking data (GetCurrentMonthLeaderboardRankingAdminV1)

    Get rankings in current month leaderboard.

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/month

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (Current month leaderboard ranking retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71130: leaderboard config not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetCurrentMonthLeaderboardRankingAdminV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        previous_version=previous_version,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetCurrentMonthLeaderboardRankingPublicV1)
def get_current_month_leaderboard_ranking_public_v1(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get current month leaderboard ranking data (GetCurrentMonthLeaderboardRankingPublicV1)

    Get rankings in current month leaderboard.

    Properties:
        url: /leaderboard/v1/public/namespaces/{namespace}/leaderboards/{leaderboardCode}/month

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (Current month leaderboard retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetCurrentMonthLeaderboardRankingPublicV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        previous_version=previous_version,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetCurrentMonthLeaderboardRankingPublicV1)
async def get_current_month_leaderboard_ranking_public_v1_async(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get current month leaderboard ranking data (GetCurrentMonthLeaderboardRankingPublicV1)

    Get rankings in current month leaderboard.

    Properties:
        url: /leaderboard/v1/public/namespaces/{namespace}/leaderboards/{leaderboardCode}/month

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (Current month leaderboard retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetCurrentMonthLeaderboardRankingPublicV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        previous_version=previous_version,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetCurrentSeasonLeaderboardRankingAdminV1)
def get_current_season_leaderboard_ranking_admin_v1(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get current season leaderboard ranking data (GetCurrentSeasonLeaderboardRankingAdminV1)

    Get rankings in current season leaderboard.

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/season

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (Current season leaderboard ranking retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71130: leaderboard config not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetCurrentSeasonLeaderboardRankingAdminV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        previous_version=previous_version,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetCurrentSeasonLeaderboardRankingAdminV1)
async def get_current_season_leaderboard_ranking_admin_v1_async(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get current season leaderboard ranking data (GetCurrentSeasonLeaderboardRankingAdminV1)

    Get rankings in current season leaderboard.

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/season

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (Current season leaderboard ranking retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71130: leaderboard config not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetCurrentSeasonLeaderboardRankingAdminV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        previous_version=previous_version,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetCurrentSeasonLeaderboardRankingPublicV1)
def get_current_season_leaderboard_ranking_public_v1(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get current season leaderboard ranking data (GetCurrentSeasonLeaderboardRankingPublicV1)

    Get rankings in current season leaderboard.

    Properties:
        url: /leaderboard/v1/public/namespaces/{namespace}/leaderboards/{leaderboardCode}/season

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (Current season leaderboard retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetCurrentSeasonLeaderboardRankingPublicV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        previous_version=previous_version,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetCurrentSeasonLeaderboardRankingPublicV1)
async def get_current_season_leaderboard_ranking_public_v1_async(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get current season leaderboard ranking data (GetCurrentSeasonLeaderboardRankingPublicV1)

    Get rankings in current season leaderboard.

    Properties:
        url: /leaderboard/v1/public/namespaces/{namespace}/leaderboards/{leaderboardCode}/season

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (Current season leaderboard retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetCurrentSeasonLeaderboardRankingPublicV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        previous_version=previous_version,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetCurrentWeekLeaderboardRankingAdminV1)
def get_current_week_leaderboard_ranking_admin_v1(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get current week leaderboard ranking data (GetCurrentWeekLeaderboardRankingAdminV1)

    Get rankings in current week leaderboard.

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/week

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (Current week leaderboard ranking retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71130: leaderboard config not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetCurrentWeekLeaderboardRankingAdminV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        previous_version=previous_version,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetCurrentWeekLeaderboardRankingAdminV1)
async def get_current_week_leaderboard_ranking_admin_v1_async(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get current week leaderboard ranking data (GetCurrentWeekLeaderboardRankingAdminV1)

    Get rankings in current week leaderboard.

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/week

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (Current week leaderboard ranking retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71130: leaderboard config not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetCurrentWeekLeaderboardRankingAdminV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        previous_version=previous_version,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetCurrentWeekLeaderboardRankingPublicV1)
def get_current_week_leaderboard_ranking_public_v1(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get current week leaderboard ranking data (GetCurrentWeekLeaderboardRankingPublicV1)

    Get rankings in current week leaderboard.

    Properties:
        url: /leaderboard/v1/public/namespaces/{namespace}/leaderboards/{leaderboardCode}/week

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (Current week leaderboard retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetCurrentWeekLeaderboardRankingPublicV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        previous_version=previous_version,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetCurrentWeekLeaderboardRankingPublicV1)
async def get_current_week_leaderboard_ranking_public_v1_async(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get current week leaderboard ranking data (GetCurrentWeekLeaderboardRankingPublicV1)

    Get rankings in current week leaderboard.

    Properties:
        url: /leaderboard/v1/public/namespaces/{namespace}/leaderboards/{leaderboardCode}/week

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (Current week leaderboard retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetCurrentWeekLeaderboardRankingPublicV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        previous_version=previous_version,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetTodayLeaderboardRankingAdminV1)
def get_today_leaderboard_ranking_admin_v1(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get today leaderboard ranking data (GetTodayLeaderboardRankingAdminV1)

    Get rankings in today leaderboard.

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/today

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (Today leaderboard ranking retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71130: leaderboard config not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetTodayLeaderboardRankingAdminV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        previous_version=previous_version,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetTodayLeaderboardRankingAdminV1)
async def get_today_leaderboard_ranking_admin_v1_async(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get today leaderboard ranking data (GetTodayLeaderboardRankingAdminV1)

    Get rankings in today leaderboard.

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/today

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (Today leaderboard ranking retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71130: leaderboard config not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetTodayLeaderboardRankingAdminV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        previous_version=previous_version,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetTodayLeaderboardRankingPublicV1)
def get_today_leaderboard_ranking_public_v1(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get today leaderboard ranking data (GetTodayLeaderboardRankingPublicV1)

    Get rankings in today leaderboard.

    Properties:
        url: /leaderboard/v1/public/namespaces/{namespace}/leaderboards/{leaderboardCode}/today

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (Today leaderboard retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetTodayLeaderboardRankingPublicV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        previous_version=previous_version,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetTodayLeaderboardRankingPublicV1)
async def get_today_leaderboard_ranking_public_v1_async(
    leaderboard_code: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get today leaderboard ranking data (GetTodayLeaderboardRankingPublicV1)

    Get rankings in today leaderboard.

    Properties:
        url: /leaderboard/v1/public/namespaces/{namespace}/leaderboards/{leaderboardCode}/today

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsGetLeaderboardRankingResp (Today leaderboard retrieved)

        400: Bad Request - ResponseErrorResponse (20002: validation error)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found | 71235: leaderboard ranking not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error | 71236: leaderboard ranking count failed)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetTodayLeaderboardRankingPublicV1.create(
        leaderboard_code=leaderboard_code,
        limit=limit,
        offset=offset,
        previous_version=previous_version,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetUserRankingAdminV1)
def get_user_ranking_admin_v1(
    leaderboard_code: str,
    user_id: str,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user ranking (getUserRankingAdminV1)

    Get user ranking in leaderboard

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/users/{userId}

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsUserRankingResponse (User ranking retrieved)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found | 71237: leaderboard ranking not created for inactive leaderboard | 71233: user ranking data not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetUserRankingAdminV1.create(
        leaderboard_code=leaderboard_code,
        user_id=user_id,
        previous_version=previous_version,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetUserRankingAdminV1)
async def get_user_ranking_admin_v1_async(
    leaderboard_code: str,
    user_id: str,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user ranking (getUserRankingAdminV1)

    Get user ranking in leaderboard

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/users/{userId}

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsUserRankingResponse (User ranking retrieved)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found | 71237: leaderboard ranking not created for inactive leaderboard | 71233: user ranking data not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetUserRankingAdminV1.create(
        leaderboard_code=leaderboard_code,
        user_id=user_id,
        previous_version=previous_version,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetUserRankingPublicV1)
def get_user_ranking_public_v1(
    leaderboard_code: str,
    user_id: str,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user ranking (getUserRankingPublicV1)

    Get user ranking in leaderboard

    Properties:
        url: /leaderboard/v1/public/namespaces/{namespace}/leaderboards/{leaderboardCode}/users/{userId}

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsUserRankingResponse (User ranking retrieved)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found | 71237: leaderboard ranking not created for inactive leaderboard | 71233: user ranking data not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetUserRankingPublicV1.create(
        leaderboard_code=leaderboard_code,
        user_id=user_id,
        previous_version=previous_version,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetUserRankingPublicV1)
async def get_user_ranking_public_v1_async(
    leaderboard_code: str,
    user_id: str,
    previous_version: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user ranking (getUserRankingPublicV1)

    Get user ranking in leaderboard

    Properties:
        url: /leaderboard/v1/public/namespaces/{namespace}/leaderboards/{leaderboardCode}/users/{userId}

        method: GET

        tags: ["LeaderboardData"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        previous_version: (previousVersion) OPTIONAL int in query

    Responses:
        200: OK - ModelsUserRankingResponse (User ranking retrieved)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71230: leaderboard configuration not found | 71237: leaderboard ranking not created for inactive leaderboard | 71233: user ranking data not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetUserRankingPublicV1.create(
        leaderboard_code=leaderboard_code,
        user_id=user_id,
        previous_version=previous_version,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateUserPointAdminV1)
def update_user_point_admin_v1(
    body: ModelsUpdateUserPointAdminV1Request,
    leaderboard_code: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update user point (updateUserPointAdminV1)

    Update user point in a leaderboard. This endpoint uses for test utility only.




    Other detail info:






      * Returns: user ranking

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/users/{userId}

        method: PUT

        tags: ["LeaderboardData"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUpdateUserPointAdminV1Request in body

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsUpdateUserPointAdminV1Response (User point updated)

        400: Bad Request - ResponseErrorResponse (20002: validation error | 20019: unable to parse request body)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71130: leaderboard config not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateUserPointAdminV1.create(
        body=body,
        leaderboard_code=leaderboard_code,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateUserPointAdminV1)
async def update_user_point_admin_v1_async(
    body: ModelsUpdateUserPointAdminV1Request,
    leaderboard_code: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update user point (updateUserPointAdminV1)

    Update user point in a leaderboard. This endpoint uses for test utility only.




    Other detail info:






      * Returns: user ranking

    Properties:
        url: /leaderboard/v1/admin/namespaces/{namespace}/leaderboards/{leaderboardCode}/users/{userId}

        method: PUT

        tags: ["LeaderboardData"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsUpdateUserPointAdminV1Request in body

        leaderboard_code: (leaderboardCode) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsUpdateUserPointAdminV1Response (User point updated)

        400: Bad Request - ResponseErrorResponse (20002: validation error | 20019: unable to parse request body)

        401: Unauthorized - ResponseErrorResponse (20001: unauthorized access)

        403: Forbidden - ResponseErrorResponse (20013: insufficient permissions)

        404: Not Found - ResponseErrorResponse (71130: leaderboard config not found)

        500: Internal Server Error - ResponseErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateUserPointAdminV1.create(
        body=body,
        leaderboard_code=leaderboard_code,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Chat Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from .utils import randomize

from ..api.chat.models import ApiAddMemberParams
from ..api.chat.models import ApiCreateNamespaceTopicParams
from ..api.chat.models import ApiCreateTopicParams
from ..api.chat.models import ApiCreateTopicResponse
from ..api.chat.models import ApiMuteUserRequest
from ..api.chat.models import ApiMutedTopicResponse
from ..api.chat.models import ApiSendChatParams
from ..api.chat.models import ApiUnmuteUserRequest
from ..api.chat.models import ApiUpdateTopicParams
from ..api.chat.models import LogAppMessageDeclaration
from ..api.chat.models import MessageActionAddUserToTopicResult
from ..api.chat.models import MessageActionDeleteTopicResult
from ..api.chat.models import ModelsAddInboxCategoryRequest
from ..api.chat.models import ModelsAddInboxCategoryResponse
from ..api.chat.models import ModelsBanTopicMemberParam
from ..api.chat.models import ModelsBanTopicMemberResult
from ..api.chat.models import ModelsCategoryHook
from ..api.chat.models import ModelsChannelTopicResponse
from ..api.chat.models import ModelsChannelTopicSummaryResponse
from ..api.chat.models import ModelsChannelTopicWithPaginationResponse
from ..api.chat.models import ModelsChatMessageResponse
from ..api.chat.models import ModelsChatMessageWithPaginationResponse
from ..api.chat.models import ModelsChatSnapshotMessage
from ..api.chat.models import ModelsChatSnapshots
from ..api.chat.models import ModelsConfig
from ..api.chat.models import ModelsConfigExport
from ..api.chat.models import ModelsConfigList
from ..api.chat.models import ModelsConfigResponse
from ..api.chat.models import ModelsDictionary
from ..api.chat.models import ModelsDictionaryChild
from ..api.chat.models import ModelsDictionaryExport
from ..api.chat.models import ModelsDictionaryExportItem
from ..api.chat.models import ModelsDictionaryGroup
from ..api.chat.models import ModelsDictionaryImportResult
from ..api.chat.models import ModelsDictionaryInsertBulkRequest
from ..api.chat.models import ModelsDictionaryInsertRequest
from ..api.chat.models import ModelsDictionaryQueryResult
from ..api.chat.models import ModelsDictionaryUpdateRequest
from ..api.chat.models import ModelsDictionaryWithChildren
from ..api.chat.models import ModelsDictionaryWordChanges
from ..api.chat.models import ModelsGetInboxCategoriesResponseItem
from ..api.chat.models import ModelsGetInboxMessagesResponse
from ..api.chat.models import ModelsGetInboxMessagesResponseData
from ..api.chat.models import ModelsGetInboxStatsResponse
from ..api.chat.models import ModelsGetInboxUsersResponse
from ..api.chat.models import ModelsImportConfigResponse
from ..api.chat.models import ModelsJSONSchemaType
from ..api.chat.models import ModelsMessageRequest
from ..api.chat.models import ModelsMessageResultWithAttributes
from ..api.chat.models import ModelsMessageStats
from ..api.chat.models import ModelsPagination
from ..api.chat.models import ModelsPublicBanTopicMembersRequest
from ..api.chat.models import ModelsPublicBanTopicMembersResponse
from ..api.chat.models import ModelsPublicConfigResponse
from ..api.chat.models import ModelsPublicUnbanTopicMembersRequest
from ..api.chat.models import ModelsPublicUnbanTopicMembersResponse
from ..api.chat.models import ModelsSaveInboxMessageRequest
from ..api.chat.models import ModelsSaveInboxMessageResponse
from ..api.chat.models import ModelsSendInboxMessageRequest
from ..api.chat.models import ModelsSendInboxMessageResponse
from ..api.chat.models import ModelsTopicInfo
from ..api.chat.models import ModelsTopicLogItem
from ..api.chat.models import ModelsTopicLogWithPaginationResponse
from ..api.chat.models import ModelsTopicMemberResponse
from ..api.chat.models import ModelsTopicMemberWithPaginationResponse
from ..api.chat.models import ModelsTopicResponse
from ..api.chat.models import ModelsUnbanTopicMemberParam
from ..api.chat.models import ModelsUnbanTopicMemberResult
from ..api.chat.models import ModelsUnsendInboxMessageRequest
from ..api.chat.models import ModelsUnsendInboxMessageResponse
from ..api.chat.models import ModelsUpdateInboxCategoryRequest
from ..api.chat.models import ModelsUpdateInboxMessageRequest
from ..api.chat.models import ModelsUserInbox
from ..api.chat.models import ResponseError
from ..api.chat.models import RestapiErrorResponseBody
from ..api.chat.models import TopicInfoMember


def create_api_add_member_params_example() -> ApiAddMemberParams:
    instance = ApiAddMemberParams()
    instance.is_admin = randomize("bool")
    return instance


def create_api_create_namespace_topic_params_example() -> ApiCreateNamespaceTopicParams:
    instance = ApiCreateNamespaceTopicParams()
    instance.description = randomize()
    instance.name = randomize()
    return instance


def create_api_create_topic_params_example() -> ApiCreateTopicParams:
    instance = ApiCreateTopicParams()
    instance.admins = [randomize()]
    instance.description = randomize()
    instance.is_channel = randomize("bool")
    instance.is_joinable = randomize("bool")
    instance.members = [randomize()]
    instance.name = randomize()
    instance.type_ = randomize()
    instance.shard_limit = randomize("int", min_val=1, max_val=1000)
    return instance


def create_api_create_topic_response_example() -> ApiCreateTopicResponse:
    instance = ApiCreateTopicResponse()
    instance.created_at = randomize("int", min_val=1, max_val=1000)
    instance.created_by = randomize()
    instance.description = randomize()
    instance.is_channel = randomize("bool")
    instance.is_joinable = randomize("bool")
    instance.name = randomize()
    instance.namespace = randomize("slug")
    instance.topic_id = randomize()
    instance.type_ = randomize()
    return instance


def create_api_mute_user_request_example() -> ApiMuteUserRequest:
    instance = ApiMuteUserRequest()
    instance.duration = randomize("int", min_val=1, max_val=1000)
    instance.user_id = randomize("uid")
    return instance


def create_api_muted_topic_response_example() -> ApiMutedTopicResponse:
    instance = ApiMutedTopicResponse()
    instance.expiration_time = randomize("int", min_val=1, max_val=1000)
    instance.remaining_time = randomize("int", min_val=1, max_val=1000)
    instance.topic_id = randomize()
    return instance


def create_api_send_chat_params_example() -> ApiSendChatParams:
    instance = ApiSendChatParams()
    instance.message = randomize()
    return instance


def create_api_unmute_user_request_example() -> ApiUnmuteUserRequest:
    instance = ApiUnmuteUserRequest()
    instance.user_id = randomize("uid")
    return instance


def create_api_update_topic_params_example() -> ApiUpdateTopicParams:
    instance = ApiUpdateTopicParams()
    instance.description = randomize()
    instance.is_joinable = randomize("bool")
    instance.name = randomize()
    return instance


def create_log_app_message_declaration_example() -> LogAppMessageDeclaration:
    instance = LogAppMessageDeclaration()
    instance.attributes = [randomize()]
    instance.code = randomize()
    instance.code_name = randomize()
    instance.section = randomize()
    instance.service = randomize()
    instance.text = randomize()
    return instance


def create_message_action_add_user_to_topic_result_example() -> (
    MessageActionAddUserToTopicResult
):
    instance = MessageActionAddUserToTopicResult()
    instance.processed = randomize("int", min_val=1, max_val=1000)
    instance.topic_id = randomize()
    instance.user_id = randomize("uid")
    return instance


def create_message_action_delete_topic_result_example() -> (
    MessageActionDeleteTopicResult
):
    instance = MessageActionDeleteTopicResult()
    instance.processed = randomize("int", min_val=1, max_val=1000)
    instance.topic_id = randomize()
    return instance


def create_models_add_inbox_category_request_example() -> ModelsAddInboxCategoryRequest:
    instance = ModelsAddInboxCategoryRequest()
    instance.enabled = randomize("bool")
    instance.expires_in = randomize("int", min_val=1, max_val=1000)
    instance.name = randomize()
    instance.save_inbox = randomize("bool")
    instance.send_notification = randomize("bool")
    instance.hook = create_models_category_hook_example()
    instance.json_schema = {randomize(): randomize()}
    return instance


def create_models_add_inbox_category_response_example() -> (
    ModelsAddInboxCategoryResponse
):
    instance = ModelsAddInboxCategoryResponse()
    instance.enabled = randomize("bool")
    instance.expires_in = randomize("int", min_val=1, max_val=1000)
    instance.name = randomize()
    instance.save_inbox = randomize("bool")
    instance.send_notification = randomize("bool")
    instance.hook = create_models_category_hook_example()
    instance.json_schema = {randomize(): randomize()}
    return instance


def create_models_ban_topic_member_param_example() -> ModelsBanTopicMemberParam:
    instance = ModelsBanTopicMemberParam()
    instance.user_ids = [randomize()]
    return instance


def create_models_ban_topic_member_result_example() -> ModelsBanTopicMemberResult:
    instance = ModelsBanTopicMemberResult()
    instance.user_ids = [randomize()]
    return instance


def create_models_category_hook_example() -> ModelsCategoryHook:
    instance = ModelsCategoryHook()
    instance.driver = randomize()
    instance.params = {randomize(): randomize()}
    return instance


def create_models_channel_topic_response_example() -> ModelsChannelTopicResponse:
    instance = ModelsChannelTopicResponse()
    instance.created_at = randomize("int", min_val=1, max_val=1000)
    instance.created_by = randomize()
    instance.description = randomize()
    instance.is_joinable = randomize("bool")
    instance.message_per_minutes = randomize("int", min_val=1, max_val=1000)
    instance.name = randomize()
    instance.namespace = randomize("slug")
    instance.shard_limit = randomize("int", min_val=1, max_val=1000)
    instance.shard_number = randomize("int", min_val=1, max_val=1000)
    instance.topic_id = randomize()
    instance.total_member = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_channel_topic_summary_response_example() -> (
    ModelsChannelTopicSummaryResponse
):
    instance = ModelsChannelTopicSummaryResponse()
    instance.total_channel = randomize("int", min_val=1, max_val=1000)
    instance.total_shard = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_channel_topic_with_pagination_response_example() -> (
    ModelsChannelTopicWithPaginationResponse
):
    instance = ModelsChannelTopicWithPaginationResponse()
    instance.data = [create_models_channel_topic_response_example()]
    instance.paging = create_models_pagination_example()
    instance.total_data = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_chat_message_response_example() -> ModelsChatMessageResponse:
    instance = ModelsChatMessageResponse()
    instance.from_ = randomize()
    instance.id_ = randomize()
    instance.message = randomize()
    instance.topic_id = randomize()
    instance.read_at = randomize("int", min_val=1, max_val=1000)
    instance.received_at = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_chat_message_with_pagination_response_example() -> (
    ModelsChatMessageWithPaginationResponse
):
    instance = ModelsChatMessageWithPaginationResponse()
    instance.data = [create_models_chat_message_response_example()]
    instance.paging = create_models_pagination_example()
    instance.total_data = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_chat_snapshot_message_example() -> ModelsChatSnapshotMessage:
    instance = ModelsChatSnapshotMessage()
    instance.chat_id = randomize()
    instance.created_at = randomize("int", min_val=1, max_val=1000)
    instance.message = randomize()
    instance.sender_id = randomize()
    return instance


def create_models_chat_snapshots_example() -> ModelsChatSnapshots:
    instance = ModelsChatSnapshots()
    instance.chat_id = randomize()
    instance.created_at = randomize("int", min_val=1, max_val=1000)
    instance.joined_topics = [randomize()]
    instance.messages = [create_models_chat_snapshot_message_example()]
    instance.namespace = randomize("slug")
    instance.sender_id = randomize()
    instance.ticket_id = randomize()
    instance.topic_id = randomize()
    return instance


def create_models_config_example() -> ModelsConfig:
    instance = ModelsConfig()
    instance.chat_rate_limit_burst = randomize("int", min_val=1, max_val=1000)
    instance.chat_rate_limit_duration = randomize("int", min_val=1, max_val=1000)
    instance.concurrent_users_limit = randomize("int", min_val=1, max_val=1000)
    instance.enable_profanity_filter = randomize("bool")
    instance.filter_app_name = randomize()
    instance.filter_param = randomize()
    instance.filter_type = randomize()
    instance.general_rate_limit_burst = randomize("int", min_val=1, max_val=1000)
    instance.general_rate_limit_duration = randomize("int", min_val=1, max_val=1000)
    instance.namespace = randomize("slug")
    instance.shard_capacity_limit = randomize("int", min_val=1, max_val=1000)
    instance.shard_default_limit = randomize("int", min_val=1, max_val=1000)
    instance.shard_hard_limit = randomize("int", min_val=1, max_val=1000)
    instance.spam_chat_burst = randomize("int", min_val=1, max_val=1000)
    instance.spam_chat_duration = randomize("int", min_val=1, max_val=1000)
    instance.spam_mute_duration = randomize("int", min_val=1, max_val=1000)
    instance.default_dictionary_loaded = randomize("bool")
    instance.enable_clan_chat = randomize("bool")
    instance.enable_manual_topic_creation = randomize("bool")
    instance.max_chat_message_length = randomize("int", min_val=1, max_val=1000)
    instance.use_default_dictionary = randomize("bool")
    return instance


def create_models_config_export_example() -> ModelsConfigExport:
    instance = ModelsConfigExport()
    instance.chat_rate_limit_burst = randomize("int", min_val=1, max_val=1000)
    instance.chat_rate_limit_duration = randomize("int", min_val=1, max_val=1000)
    instance.concurrent_users_limit = randomize("int", min_val=1, max_val=1000)
    instance.general_rate_limit_burst = randomize("int", min_val=1, max_val=1000)
    instance.general_rate_limit_duration = randomize("int", min_val=1, max_val=1000)
    instance.namespace = randomize("slug")
    instance.enable_clan_chat = randomize("bool")
    instance.enable_manual_topic_creation = randomize("bool")
    instance.enable_profanity_filter = randomize("bool")
    instance.filter_app_name = randomize()
    instance.filter_param = randomize()
    instance.filter_type = randomize()
    instance.shard_capacity_limit = randomize("int", min_val=1, max_val=1000)
    instance.shard_default_limit = randomize("int", min_val=1, max_val=1000)
    instance.shard_hard_limit = randomize("int", min_val=1, max_val=1000)
    instance.spam_chat_burst = randomize("int", min_val=1, max_val=1000)
    instance.spam_chat_duration = randomize("int", min_val=1, max_val=1000)
    instance.spam_mute_duration = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_config_list_example() -> ModelsConfigList:
    instance = ModelsConfigList()
    instance.configs = [create_models_config_example()]
    return instance


def create_models_config_response_example() -> ModelsConfigResponse:
    instance = ModelsConfigResponse()
    instance.chat_rate_limit_burst = randomize("int", min_val=1, max_val=1000)
    instance.chat_rate_limit_duration = randomize("int", min_val=1, max_val=1000)
    instance.concurrent_users_limit = randomize("int", min_val=1, max_val=1000)
    instance.enable_clan_chat = randomize("bool")
    instance.enable_manual_topic_creation = randomize("bool")
    instance.enable_profanity_filter = randomize("bool")
    instance.filter_app_name = randomize()
    instance.filter_param = randomize()
    instance.filter_type = randomize()
    instance.general_rate_limit_burst = randomize("int", min_val=1, max_val=1000)
    instance.general_rate_limit_duration = randomize("int", min_val=1, max_val=1000)
    instance.max_chat_message_length = randomize("int", min_val=1, max_val=1000)
    instance.shard_capacity_limit = randomize("int", min_val=1, max_val=1000)
    instance.shard_default_limit = randomize("int", min_val=1, max_val=1000)
    instance.shard_hard_limit = randomize("int", min_val=1, max_val=1000)
    instance.spam_chat_burst = randomize("int", min_val=1, max_val=1000)
    instance.spam_chat_duration = randomize("int", min_val=1, max_val=1000)
    instance.spam_mute_duration = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_dictionary_example() -> ModelsDictionary:
    instance = ModelsDictionary()
    instance.id_ = randomize()
    instance.namespace = randomize("slug")
    instance.word = randomize()
    instance.word_type = randomize()
    instance.parent_id = randomize()
    return instance


def create_models_dictionary_child_example() -> ModelsDictionaryChild:
    instance = ModelsDictionaryChild()
    instance.id_ = randomize()
    instance.word = randomize()
    return instance


def create_models_dictionary_export_example() -> ModelsDictionaryExport:
    instance = ModelsDictionaryExport()
    instance.dictionaries = [create_models_dictionary_export_item_example()]
    return instance


def create_models_dictionary_export_item_example() -> ModelsDictionaryExportItem:
    instance = ModelsDictionaryExportItem()
    instance.word = randomize()
    instance.false_negative = [randomize()]
    instance.false_positive = [randomize()]
    return instance


def create_models_dictionary_group_example() -> ModelsDictionaryGroup:
    instance = ModelsDictionaryGroup()
    instance.count = randomize("int", min_val=1, max_val=1000)
    instance.name = randomize()
    return instance


def create_models_dictionary_import_result_example() -> ModelsDictionaryImportResult:
    instance = ModelsDictionaryImportResult()
    instance.words = create_models_dictionary_word_changes_example()
    return instance


def create_models_dictionary_insert_bulk_request_example() -> (
    ModelsDictionaryInsertBulkRequest
):
    instance = ModelsDictionaryInsertBulkRequest()
    instance.dictionaries = [create_models_dictionary_insert_request_example()]
    return instance


def create_models_dictionary_insert_request_example() -> ModelsDictionaryInsertRequest:
    instance = ModelsDictionaryInsertRequest()
    instance.false_negative = [randomize()]
    instance.false_positive = [randomize()]
    instance.word = randomize()
    instance.word_type = randomize()
    return instance


def create_models_dictionary_query_result_example() -> ModelsDictionaryQueryResult:
    instance = ModelsDictionaryQueryResult()
    instance.data = [create_models_dictionary_with_children_example()]
    instance.next_ = randomize()
    instance.previous = randomize()
    return instance


def create_models_dictionary_update_request_example() -> ModelsDictionaryUpdateRequest:
    instance = ModelsDictionaryUpdateRequest()
    instance.false_negative = [randomize()]
    instance.false_positive = [randomize()]
    instance.word = randomize()
    instance.word_type = randomize()
    return instance


def create_models_dictionary_with_children_example() -> ModelsDictionaryWithChildren:
    instance = ModelsDictionaryWithChildren()
    instance.id_ = randomize()
    instance.namespace = randomize("slug")
    instance.word = randomize()
    instance.word_type = randomize()
    instance.false_negatives = [create_models_dictionary_child_example()]
    instance.false_positives = [create_models_dictionary_child_example()]
    instance.parent_id = randomize()
    return instance


def create_models_dictionary_word_changes_example() -> ModelsDictionaryWordChanges:
    instance = ModelsDictionaryWordChanges()
    instance.added = [randomize()]
    instance.failed = [randomize()]
    instance.ignored = [randomize()]
    instance.replaced = [randomize()]
    instance.unchanged = [randomize()]
    return instance


def create_models_get_inbox_categories_response_item_example() -> (
    ModelsGetInboxCategoriesResponseItem
):
    instance = ModelsGetInboxCategoriesResponseItem()
    instance.enabled = randomize("bool")
    instance.expires_in = randomize("int", min_val=1, max_val=1000)
    instance.name = randomize()
    instance.save_inbox = randomize("bool")
    instance.send_notification = randomize("bool")
    instance.hook = create_models_category_hook_example()
    instance.json_schema = {randomize(): randomize()}
    return instance


def create_models_get_inbox_messages_response_example() -> (
    ModelsGetInboxMessagesResponse
):
    instance = ModelsGetInboxMessagesResponse()
    instance.data = [create_models_get_inbox_messages_response_data_example()]
    instance.next_ = randomize()
    instance.previous = randomize()
    return instance


def create_models_get_inbox_messages_response_data_example() -> (
    ModelsGetInboxMessagesResponseData
):
    instance = ModelsGetInboxMessagesResponseData()
    instance.created_at = randomize("int", min_val=1, max_val=1000)
    instance.expired_at = randomize("int", min_val=1, max_val=1000)
    instance.id_ = randomize()
    instance.scope = randomize()
    instance.sender_id = randomize()
    instance.status = randomize()
    instance.updated_at = randomize("int", min_val=1, max_val=1000)
    instance.category = randomize()
    instance.message = {randomize(): randomize()}
    instance.user_ids = [randomize()]
    return instance


def create_models_get_inbox_stats_response_example() -> ModelsGetInboxStatsResponse:
    instance = ModelsGetInboxStatsResponse()
    instance.data = [create_models_message_stats_example()]
    return instance


def create_models_get_inbox_users_response_example() -> ModelsGetInboxUsersResponse:
    instance = ModelsGetInboxUsersResponse()
    instance.data = [create_models_user_inbox_example()]
    instance.next_ = randomize()
    instance.previous = randomize()
    return instance


def create_models_import_config_response_example() -> ModelsImportConfigResponse:
    instance = ModelsImportConfigResponse()
    instance.failed_configs = [randomize()]
    instance.ignored_configs = [randomize()]
    instance.new_configs = [randomize()]
    instance.replaced_configs = [randomize()]
    return instance


def create_models_json_schema_type_example() -> ModelsJSONSchemaType:
    instance = ModelsJSONSchemaType()
    return instance


def create_models_message_request_example() -> ModelsMessageRequest:
    instance = ModelsMessageRequest()
    instance.message = randomize()
    instance.timestamp = randomize("int", min_val=1, max_val=1000)
    instance.topic_id = randomize()
    instance.topic_type = randomize()
    instance.user_id = randomize("uid")
    return instance


def create_models_message_result_with_attributes_example() -> (
    ModelsMessageResultWithAttributes
):
    instance = ModelsMessageResultWithAttributes()
    instance.action = randomize()
    instance.final_message = randomize()
    instance.id_ = randomize()
    instance.timestamp = randomize("int", min_val=1, max_val=1000)
    instance.attributes = {randomize(): randomize()}
    instance.cencored_words = [randomize()]
    instance.classifications = [randomize()]
    instance.reference_id = randomize()
    return instance


def create_models_message_stats_example() -> ModelsMessageStats:
    instance = ModelsMessageStats()
    instance.id_ = randomize()
    instance.message_read = randomize("int", min_val=1, max_val=1000)
    instance.message_stored = randomize("int", min_val=1, max_val=1000)
    instance.notification_sent = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_pagination_example() -> ModelsPagination:
    instance = ModelsPagination()
    instance.next_ = randomize()
    instance.previous = randomize()
    return instance


def create_models_public_ban_topic_members_request_example() -> (
    ModelsPublicBanTopicMembersRequest
):
    instance = ModelsPublicBanTopicMembersRequest()
    instance.user_i_ds = [randomize()]
    return instance


def create_models_public_ban_topic_members_response_example() -> (
    ModelsPublicBanTopicMembersResponse
):
    instance = ModelsPublicBanTopicMembersResponse()
    instance.user_i_ds = [randomize()]
    return instance


def create_models_public_config_response_example() -> ModelsPublicConfigResponse:
    instance = ModelsPublicConfigResponse()
    instance.chat_rate_limit_burst = randomize("int", min_val=1, max_val=1000)
    instance.chat_rate_limit_duration = randomize("int", min_val=1, max_val=1000)
    instance.general_rate_limit_burst = randomize("int", min_val=1, max_val=1000)
    instance.general_rate_limit_duration = randomize("int", min_val=1, max_val=1000)
    instance.max_chat_message_length = randomize("int", min_val=1, max_val=1000)
    instance.spam_chat_burst = randomize("int", min_val=1, max_val=1000)
    instance.spam_chat_duration = randomize("int", min_val=1, max_val=1000)
    instance.spam_mute_duration = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_public_unban_topic_members_request_example() -> (
    ModelsPublicUnbanTopicMembersRequest
):
    instance = ModelsPublicUnbanTopicMembersRequest()
    instance.user_i_ds = [randomize()]
    return instance


def create_models_public_unban_topic_members_response_example() -> (
    ModelsPublicUnbanTopicMembersResponse
):
    instance = ModelsPublicUnbanTopicMembersResponse()
    instance.user_i_ds = [randomize()]
    return instance


def create_models_save_inbox_message_request_example() -> ModelsSaveInboxMessageRequest:
    instance = ModelsSaveInboxMessageRequest()
    instance.expired_at = randomize("int", min_val=1, max_val=1000)
    instance.message = {randomize(): randomize()}
    instance.scope = randomize()
    instance.status = randomize()
    instance.user_ids = [randomize()]
    instance.category = randomize()
    return instance


def create_models_save_inbox_message_response_example() -> (
    ModelsSaveInboxMessageResponse
):
    instance = ModelsSaveInboxMessageResponse()
    instance.expired_at = randomize("int", min_val=1, max_val=1000)
    instance.id_ = randomize()
    instance.scope = randomize()
    instance.status = randomize()
    instance.category = randomize()
    instance.message = {randomize(): randomize()}
    instance.user_i_ds = [randomize()]
    return instance


def create_models_send_inbox_message_request_example() -> ModelsSendInboxMessageRequest:
    instance = ModelsSendInboxMessageRequest()
    return instance


def create_models_send_inbox_message_response_example() -> (
    ModelsSendInboxMessageResponse
):
    instance = ModelsSendInboxMessageResponse()
    return instance


def create_models_topic_info_example() -> ModelsTopicInfo:
    instance = ModelsTopicInfo()
    instance.created_at = randomize("int", min_val=1, max_val=1000)
    instance.id_ = randomize()
    instance.name = randomize()
    instance.sub_type = randomize()
    instance.type_ = randomize()
    instance.deleted_at = randomize("int", min_val=1, max_val=1000)
    instance.members = [create_topic_info_member_example()]
    return instance


def create_models_topic_log_item_example() -> ModelsTopicLogItem:
    instance = ModelsTopicLogItem()
    instance.created_at = randomize("int", min_val=1, max_val=1000)
    instance.id_ = randomize()
    instance.message = randomize()
    instance.sender_id = randomize()
    instance.topic_id = randomize()
    instance.type_ = randomize()
    instance.user_id = randomize("uid")
    return instance


def create_models_topic_log_with_pagination_response_example() -> (
    ModelsTopicLogWithPaginationResponse
):
    instance = ModelsTopicLogWithPaginationResponse()
    instance.data = [create_models_topic_log_item_example()]
    instance.paging = create_models_pagination_example()
    return instance


def create_models_topic_member_response_example() -> ModelsTopicMemberResponse:
    instance = ModelsTopicMemberResponse()
    instance.is_admin = randomize("bool")
    instance.is_banned = randomize("bool")
    instance.shard_id = randomize()
    instance.user_id = randomize("uid")
    return instance


def create_models_topic_member_with_pagination_response_example() -> (
    ModelsTopicMemberWithPaginationResponse
):
    instance = ModelsTopicMemberWithPaginationResponse()
    instance.data = [create_models_topic_member_response_example()]
    instance.paging = create_models_pagination_example()
    instance.total_data = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_topic_response_example() -> ModelsTopicResponse:
    instance = ModelsTopicResponse()
    instance.created_at = randomize("int", min_val=1, max_val=1000)
    instance.created_by = randomize()
    instance.last_message_at = randomize("int", min_val=1, max_val=1000)
    instance.name = randomize()
    instance.namespace = randomize("slug")
    instance.topic_id = randomize()
    instance.type_ = randomize()
    return instance


def create_models_unban_topic_member_param_example() -> ModelsUnbanTopicMemberParam:
    instance = ModelsUnbanTopicMemberParam()
    instance.user_ids = [randomize()]
    return instance


def create_models_unban_topic_member_result_example() -> ModelsUnbanTopicMemberResult:
    instance = ModelsUnbanTopicMemberResult()
    instance.user_ids = [randomize()]
    return instance


def create_models_unsend_inbox_message_request_example() -> (
    ModelsUnsendInboxMessageRequest
):
    instance = ModelsUnsendInboxMessageRequest()
    instance.user_ids = [randomize()]
    return instance


def create_models_unsend_inbox_message_response_example() -> (
    ModelsUnsendInboxMessageResponse
):
    instance = ModelsUnsendInboxMessageResponse()
    return instance


def create_models_update_inbox_category_request_example() -> (
    ModelsUpdateInboxCategoryRequest
):
    instance = ModelsUpdateInboxCategoryRequest()
    instance.enabled = randomize("bool")
    instance.expires_in = randomize("int", min_val=1, max_val=1000)
    instance.hook = create_models_category_hook_example()
    instance.save_inbox = randomize("bool")
    instance.send_notification = randomize("bool")
    instance.json_schema = {randomize(): randomize()}
    return instance


def create_models_update_inbox_message_request_example() -> (
    ModelsUpdateInboxMessageRequest
):
    instance = ModelsUpdateInboxMessageRequest()
    instance.expired_at = randomize("int", min_val=1, max_val=1000)
    instance.message = {randomize(): randomize()}
    instance.scope = randomize()
    instance.user_ids = [randomize()]
    return instance


def create_models_user_inbox_example() -> ModelsUserInbox:
    instance = ModelsUserInbox()
    instance.keep = randomize("bool")
    instance.read_at = randomize("int", min_val=1, max_val=1000)
    instance.user_id = randomize("uid")
    return instance


def create_response_error_example() -> ResponseError:
    instance = ResponseError()
    instance.error_code = randomize("int", min_val=1, max_val=1000)
    instance.error_message = randomize()
    return instance


def create_restapi_error_response_body_example() -> RestapiErrorResponseBody:
    instance = RestapiErrorResponseBody()
    instance.error_code = randomize("int", min_val=1, max_val=1000)
    instance.error_message = randomize()
    return instance


def create_topic_info_member_example() -> TopicInfoMember:
    instance = TopicInfoMember()
    instance.user_id = randomize("uid")
    instance.left_at = randomize("int", min_val=1, max_val=1000)
    return instance



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Inventory Service."""

__version__ = "0.1.4"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

# admin_chaining_operations
from .wrappers import admin_create_chaining_operations
from .wrappers import admin_create_chaining_operations_async

# admin_integration_configurations
from .wrappers import admin_create_integration_configuration
from .wrappers import admin_create_integration_configuration_async
from .wrappers import admin_list_integration_configurations
from .wrappers import admin_list_integration_configurations_async
from .wrappers import admin_update_integration_configuration
from .wrappers import admin_update_integration_configuration_async
from .wrappers import admin_update_status_integration_configuration
from .wrappers import admin_update_status_integration_configuration_async

# admin_inventories
from .wrappers import admin_create_inventory
from .wrappers import admin_create_inventory_async
from .wrappers import admin_get_inventory
from .wrappers import admin_get_inventory_async
from .wrappers import admin_list_inventories
from .wrappers import admin_list_inventories_async
from .wrappers import admin_purchasable
from .wrappers import admin_purchasable_async
from .wrappers import admin_update_inventory
from .wrappers import admin_update_inventory_async
from .wrappers import delete_inventory
from .wrappers import delete_inventory_async

# admin_inventory_configurations
from .wrappers import admin_create_inventory_configuration
from .wrappers import admin_create_inventory_configuration_async
from .wrappers import admin_delete_inventory_configuration
from .wrappers import admin_delete_inventory_configuration_async
from .wrappers import admin_get_inventory_configuration
from .wrappers import admin_get_inventory_configuration_async
from .wrappers import admin_list_inventory_configurations
from .wrappers import admin_list_inventory_configurations_async
from .wrappers import admin_update_inventory_configuration
from .wrappers import admin_update_inventory_configuration_async

# admin_item_types
from .wrappers import admin_create_item_type
from .wrappers import admin_create_item_type_async
from .wrappers import admin_delete_item_type
from .wrappers import admin_delete_item_type_async
from .wrappers import admin_list_item_types
from .wrappers import admin_list_item_types_async

# admin_items
from .wrappers import admin_bulk_remove_items
from .wrappers import admin_bulk_remove_items_async
from .wrappers import admin_bulk_update_my_items
from .wrappers import admin_bulk_update_my_items_async
from .wrappers import admin_consume_user_item
from .wrappers import admin_consume_user_item_async
from .wrappers import admin_get_inventory_item
from .wrappers import admin_get_inventory_item_async
from .wrappers import admin_list_items
from .wrappers import admin_list_items_async
from .wrappers import admin_save_item
from .wrappers import admin_save_item_async
from .wrappers import admin_save_item_to_inventory
from .wrappers import admin_save_item_to_inventory_async
from .wrappers import admin_sync_user_entitlements
from .wrappers import admin_sync_user_entitlements_async

# admin_tags
from .wrappers import admin_create_tag
from .wrappers import admin_create_tag_async
from .wrappers import admin_delete_tag
from .wrappers import admin_delete_tag_async
from .wrappers import admin_list_tags
from .wrappers import admin_list_tags_async

# public_inventories
from .wrappers import public_list_inventories
from .wrappers import public_list_inventories_async

# public_inventory_configurations
from .wrappers import public_list_inventory_configurations
from .wrappers import public_list_inventory_configurations_async

# public_item_types
from .wrappers import public_list_item_types
from .wrappers import public_list_item_types_async

# public_items
from .wrappers import public_bulk_remove_my_items
from .wrappers import public_bulk_remove_my_items_async
from .wrappers import public_bulk_update_my_items
from .wrappers import public_bulk_update_my_items_async
from .wrappers import public_consume_my_item
from .wrappers import public_consume_my_item_async
from .wrappers import public_get_item
from .wrappers import public_get_item_async
from .wrappers import public_list_items
from .wrappers import public_list_items_async
from .wrappers import public_move_my_items
from .wrappers import public_move_my_items_async

# public_tags
from .wrappers import public_list_tags
from .wrappers import public_list_tags_async



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelsGameRecordAdminResponse
from ..models import ModelsGameRecordRequest
from ..models import ModelsListGameRecordKeysResponse
from ..models import ModelsResponseError

from ..operations.admin_game_record import AdminDeleteGameRecordHandlerV1
from ..operations.admin_game_record import AdminGetGameRecordHandlerV1
from ..operations.admin_game_record import AdminPostGameRecordHandlerV1
from ..operations.admin_game_record import AdminPutGameRecordHandlerV1
from ..operations.admin_game_record import ListGameRecordsHandlerV1
from ..models import ModelsGameRecordAdminResponseSetByEnum


@same_doc_as(AdminDeleteGameRecordHandlerV1)
def admin_delete_game_record_handler_v1(
    key: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete game record (adminDeleteGameRecordHandlerV1)

    This endpoints delete game record in namespace-level

    Properties:
        url: /cloudsave/v1/admin/namespaces/{namespace}/records/{key}

        method: DELETE

        tags: ["AdminGameRecord"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        key: (key) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (Record deleted)

        400: Bad Request - ModelsResponseError (18201: invalid record operator, expect [%s] but actual [%s])

        401: Unauthorized - ModelsResponseError (20001: unauthorized access)

        403: Forbidden - ModelsResponseError (20013: insufficient permission)

        500: Internal Server Error - ModelsResponseError (20000: internal server error | 18040: unable to delete record)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDeleteGameRecordHandlerV1.create(
        key=key,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminDeleteGameRecordHandlerV1)
async def admin_delete_game_record_handler_v1_async(
    key: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete game record (adminDeleteGameRecordHandlerV1)

    This endpoints delete game record in namespace-level

    Properties:
        url: /cloudsave/v1/admin/namespaces/{namespace}/records/{key}

        method: DELETE

        tags: ["AdminGameRecord"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        key: (key) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (Record deleted)

        400: Bad Request - ModelsResponseError (18201: invalid record operator, expect [%s] but actual [%s])

        401: Unauthorized - ModelsResponseError (20001: unauthorized access)

        403: Forbidden - ModelsResponseError (20013: insufficient permission)

        500: Internal Server Error - ModelsResponseError (20000: internal server error | 18040: unable to delete record)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminDeleteGameRecordHandlerV1.create(
        key=key,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetGameRecordHandlerV1)
def admin_get_game_record_handler_v1(
    key: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get game record (adminGetGameRecordHandlerV1)

    Get a record by its key in namespace-level.

    Properties:
        url: /cloudsave/v1/admin/namespaces/{namespace}/records/{key}

        method: GET

        tags: ["AdminGameRecord"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        key: (key) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsGameRecordAdminResponse (Record in namespace-level retrieved)

        401: Unauthorized - ModelsResponseError (20001: unauthorized access)

        403: Forbidden - ModelsResponseError (20013: insufficient permission)

        404: Not Found - ModelsResponseError (18003: record not found)

        500: Internal Server Error - ModelsResponseError (18001: unable to get record | 18005: unable to decode record)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetGameRecordHandlerV1.create(
        key=key,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetGameRecordHandlerV1)
async def admin_get_game_record_handler_v1_async(
    key: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get game record (adminGetGameRecordHandlerV1)

    Get a record by its key in namespace-level.

    Properties:
        url: /cloudsave/v1/admin/namespaces/{namespace}/records/{key}

        method: GET

        tags: ["AdminGameRecord"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        key: (key) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsGameRecordAdminResponse (Record in namespace-level retrieved)

        401: Unauthorized - ModelsResponseError (20001: unauthorized access)

        403: Forbidden - ModelsResponseError (20013: insufficient permission)

        404: Not Found - ModelsResponseError (18003: record not found)

        500: Internal Server Error - ModelsResponseError (18001: unable to get record | 18005: unable to decode record)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetGameRecordHandlerV1.create(
        key=key,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminPostGameRecordHandlerV1)
def admin_post_game_record_handler_v1(
    body: ModelsGameRecordRequest,
    key: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Create or append game record (adminPostGameRecordHandlerV1)

    ## Description

    This endpoints will create new game record or append the existing game record.

    **Append example:**

    Example 1
    - Existing JSON:

    `{ "data1": "value" }`

    - New JSON:

    `{ "data2": "new value" }`

    - Result:

    `{ "data1": "value", "data2": "new value" }`


    Example 2
    - Existing JSON:

    `{ "data1": { "data2": "value" }`

    - New JSON:

    `{ "data1": { "data3": "new value" }`

    - Result:

    `{ "data1": { "data2": "value", "data3": "new value" }`


    ## Restriction
    This is the restriction of Key Naming for the record:
    1. Cannot use **"."** as the key name
    - `{ "data.2": "value" }`
    2. Cannot use **"$"** as the prefix in key names
    - `{ "$data": "value" }`
    3. Cannot use empty string in key names
    - `{ "": "value" }`


    ## Record Metadata

    Metadata allows user to define the behaviour of the record.
    Metadata can be defined in request body with field name **__META**.
    When creating record, if **__META** field is not defined, the metadata value will use the default value.
    When updating record, if **__META** field is not defined, the existing metadata value will stay as is.

    **Metadata List:**
    1. set_by (default: CLIENT, type: string)
    Indicate which party that could modify the game record.
    SERVER: record can be modified by server only.
    CLIENT: record can be modified by client and server.
    2. ttl_config (default: *empty*, type: object)
    Indicate the TTL configuration for the game record.
    action:
    - DELETE: record will be deleted after TTL is reached
    3. tags (default: *empty array*, type: array of string)
    Indicate the tagging for the game record.

    **Request Body Example:**
    ```
    {
    "__META": {
    "set_by": "SERVER",
    "ttl_config": {
    "expires_at": "2026-01-02T15:04:05Z", // should be in RFC3339 format
    "action": "DELETE"
    },
    "tags": ["tag1", "tag2"]
    }
    ...
    }
    ```

    Required Permission(s):
        - CLIENT []

    Properties:
        url: /cloudsave/v1/admin/namespaces/{namespace}/records/{key}

        method: POST

        tags: ["AdminGameRecord"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsGameRecordRequest in body

        key: (key) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        201: Created - ModelsGameRecordAdminResponse (Record in namespace-level saved)

        400: Bad Request - ModelsResponseError (18011: invalid request body | 20002: validation error | 18015: invalid request body: size of the request body must be less than [%d]MB)

        401: Unauthorized - ModelsResponseError (20001: unauthorized access)

        403: Forbidden - ModelsResponseError (20013: insufficient permission)

        500: Internal Server Error - ModelsResponseError (18012: unable to marshal request body | 20000: internal server error | 18013: unable to save record | 18005: unable to decode record)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminPostGameRecordHandlerV1.create(
        body=body,
        key=key,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminPostGameRecordHandlerV1)
async def admin_post_game_record_handler_v1_async(
    body: ModelsGameRecordRequest,
    key: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Create or append game record (adminPostGameRecordHandlerV1)

    ## Description

    This endpoints will create new game record or append the existing game record.

    **Append example:**

    Example 1
    - Existing JSON:

    `{ "data1": "value" }`

    - New JSON:

    `{ "data2": "new value" }`

    - Result:

    `{ "data1": "value", "data2": "new value" }`


    Example 2
    - Existing JSON:

    `{ "data1": { "data2": "value" }`

    - New JSON:

    `{ "data1": { "data3": "new value" }`

    - Result:

    `{ "data1": { "data2": "value", "data3": "new value" }`


    ## Restriction
    This is the restriction of Key Naming for the record:
    1. Cannot use **"."** as the key name
    - `{ "data.2": "value" }`
    2. Cannot use **"$"** as the prefix in key names
    - `{ "$data": "value" }`
    3. Cannot use empty string in key names
    - `{ "": "value" }`


    ## Record Metadata

    Metadata allows user to define the behaviour of the record.
    Metadata can be defined in request body with field name **__META**.
    When creating record, if **__META** field is not defined, the metadata value will use the default value.
    When updating record, if **__META** field is not defined, the existing metadata value will stay as is.

    **Metadata List:**
    1. set_by (default: CLIENT, type: string)
    Indicate which party that could modify the game record.
    SERVER: record can be modified by server only.
    CLIENT: record can be modified by client and server.
    2. ttl_config (default: *empty*, type: object)
    Indicate the TTL configuration for the game record.
    action:
    - DELETE: record will be deleted after TTL is reached
    3. tags (default: *empty array*, type: array of string)
    Indicate the tagging for the game record.

    **Request Body Example:**
    ```
    {
    "__META": {
    "set_by": "SERVER",
    "ttl_config": {
    "expires_at": "2026-01-02T15:04:05Z", // should be in RFC3339 format
    "action": "DELETE"
    },
    "tags": ["tag1", "tag2"]
    }
    ...
    }
    ```

    Required Permission(s):
        - CLIENT []

    Properties:
        url: /cloudsave/v1/admin/namespaces/{namespace}/records/{key}

        method: POST

        tags: ["AdminGameRecord"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsGameRecordRequest in body

        key: (key) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        201: Created - ModelsGameRecordAdminResponse (Record in namespace-level saved)

        400: Bad Request - ModelsResponseError (18011: invalid request body | 20002: validation error | 18015: invalid request body: size of the request body must be less than [%d]MB)

        401: Unauthorized - ModelsResponseError (20001: unauthorized access)

        403: Forbidden - ModelsResponseError (20013: insufficient permission)

        500: Internal Server Error - ModelsResponseError (18012: unable to marshal request body | 20000: internal server error | 18013: unable to save record | 18005: unable to decode record)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminPostGameRecordHandlerV1.create(
        body=body,
        key=key,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminPutGameRecordHandlerV1)
def admin_put_game_record_handler_v1(
    body: ModelsGameRecordRequest,
    key: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Create or replace game record (adminPutGameRecordHandlerV1)

    ## Description

    This endpoints will create new game record or replace the existing game record.

    **Replace behaviour:**
    The existing value will be replaced completely with the new value.

    Example
    - Existing JSON:

    `{ "data1": "value" }`

    - New JSON:

    `{ "data2": "new value" }`

    - Result:

    `{ "data2": "new value" }`



    ## Restriction
    This is the restriction of Key Naming for the record:
    1. Cannot use **"."** as the key name
    - `{ "data.2": "value" }`
    2. Cannot use **"$"** as the prefix in key names
    - `{ "$data": "value" }`
    3. Cannot use empty string in key names
    - `{ "": "value" }`


    ## Record Metadata

    Metadata allows user to define the behaviour of the record.
    Metadata can be defined in request body with field name **__META**.
    When creating record, if **__META** field is not defined, the metadata value will use the default value.
    When updating record, if **__META** field is not defined, the existing metadata value will stay as is.

    **Metadata List:**
    1. set_by (default: CLIENT, type: string)
    Indicate which party that could modify the game record.
    SERVER: record can be modified by server only.
    CLIENT: record can be modified by client and server.
    2. ttl_config (default: *empty*, type: object)
    Indicate the TTL configuration for the game record.
    action:
    - DELETE: record will be deleted after TTL is reached
    3. tags (default: *empty array*, type: array of string)
    Indicate the tagging for the game record.

    **Request Body Example:**
    ```
    {
    "__META": {
    "set_by": "SERVER",
    "ttl_config": {
    "expires_at": "2026-01-02T15:04:05Z", // should be in RFC3339 format
    "action": "DELETE"
    },
    "tags": ["tag1", "tag2"]
    }
    ...
    }
    ```

    Required Permission(s):
        - CLIENT []

    Properties:
        url: /cloudsave/v1/admin/namespaces/{namespace}/records/{key}

        method: PUT

        tags: ["AdminGameRecord"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsGameRecordRequest in body

        key: (key) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsGameRecordAdminResponse (Record saved)

        400: Bad Request - ModelsResponseError (18050: invalid request body | 20002: validation error | 18052: invalid request body: size of the request body must be less than [%d]MB)

        401: Unauthorized - ModelsResponseError (20001: unauthorized access)

        403: Forbidden - ModelsResponseError (20013: insufficient permission)

        500: Internal Server Error - ModelsResponseError (18051: unable to marshal request body | 20000: internal server error | 18053: unable to update record | 18005: unable to decode record)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminPutGameRecordHandlerV1.create(
        body=body,
        key=key,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminPutGameRecordHandlerV1)
async def admin_put_game_record_handler_v1_async(
    body: ModelsGameRecordRequest,
    key: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Create or replace game record (adminPutGameRecordHandlerV1)

    ## Description

    This endpoints will create new game record or replace the existing game record.

    **Replace behaviour:**
    The existing value will be replaced completely with the new value.

    Example
    - Existing JSON:

    `{ "data1": "value" }`

    - New JSON:

    `{ "data2": "new value" }`

    - Result:

    `{ "data2": "new value" }`



    ## Restriction
    This is the restriction of Key Naming for the record:
    1. Cannot use **"."** as the key name
    - `{ "data.2": "value" }`
    2. Cannot use **"$"** as the prefix in key names
    - `{ "$data": "value" }`
    3. Cannot use empty string in key names
    - `{ "": "value" }`


    ## Record Metadata

    Metadata allows user to define the behaviour of the record.
    Metadata can be defined in request body with field name **__META**.
    When creating record, if **__META** field is not defined, the metadata value will use the default value.
    When updating record, if **__META** field is not defined, the existing metadata value will stay as is.

    **Metadata List:**
    1. set_by (default: CLIENT, type: string)
    Indicate which party that could modify the game record.
    SERVER: record can be modified by server only.
    CLIENT: record can be modified by client and server.
    2. ttl_config (default: *empty*, type: object)
    Indicate the TTL configuration for the game record.
    action:
    - DELETE: record will be deleted after TTL is reached
    3. tags (default: *empty array*, type: array of string)
    Indicate the tagging for the game record.

    **Request Body Example:**
    ```
    {
    "__META": {
    "set_by": "SERVER",
    "ttl_config": {
    "expires_at": "2026-01-02T15:04:05Z", // should be in RFC3339 format
    "action": "DELETE"
    },
    "tags": ["tag1", "tag2"]
    }
    ...
    }
    ```

    Required Permission(s):
        - CLIENT []

    Properties:
        url: /cloudsave/v1/admin/namespaces/{namespace}/records/{key}

        method: PUT

        tags: ["AdminGameRecord"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ModelsGameRecordRequest in body

        key: (key) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelsGameRecordAdminResponse (Record saved)

        400: Bad Request - ModelsResponseError (18050: invalid request body | 20002: validation error | 18052: invalid request body: size of the request body must be less than [%d]MB)

        401: Unauthorized - ModelsResponseError (20001: unauthorized access)

        403: Forbidden - ModelsResponseError (20013: insufficient permission)

        500: Internal Server Error - ModelsResponseError (18051: unable to marshal request body | 20000: internal server error | 18053: unable to update record | 18005: unable to decode record)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminPutGameRecordHandlerV1.create(
        body=body,
        key=key,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(ListGameRecordsHandlerV1)
def list_game_records_handler_v1(
    limit: int,
    offset: int,
    query: Optional[str] = None,
    tags: Optional[List[str]] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query game records (listGameRecordsHandlerV1)

    Retrieve list of records key by namespace

    Properties:
        url: /cloudsave/v1/admin/namespaces/{namespace}/records

        method: GET

        tags: ["AdminGameRecord"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        query: (query) OPTIONAL str in query

        tags: (tags) OPTIONAL List[str] in query

        limit: (limit) REQUIRED int in query

        offset: (offset) REQUIRED int in query

    Responses:
        200: OK - ModelsListGameRecordKeysResponse (Retrieve list of records key by namespace)

        400: Bad Request - ModelsResponseError (18004: unable to retrieve list of key records)

        401: Unauthorized - ModelsResponseError (20001: unauthorized access)

        403: Forbidden - ModelsResponseError (20013: insufficient permission)

        500: Internal Server Error - ModelsResponseError (18001: unable to get record)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = ListGameRecordsHandlerV1.create(
        limit=limit,
        offset=offset,
        query=query,
        tags=tags,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(ListGameRecordsHandlerV1)
async def list_game_records_handler_v1_async(
    limit: int,
    offset: int,
    query: Optional[str] = None,
    tags: Optional[List[str]] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Query game records (listGameRecordsHandlerV1)

    Retrieve list of records key by namespace

    Properties:
        url: /cloudsave/v1/admin/namespaces/{namespace}/records

        method: GET

        tags: ["AdminGameRecord"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        query: (query) OPTIONAL str in query

        tags: (tags) OPTIONAL List[str] in query

        limit: (limit) REQUIRED int in query

        offset: (offset) REQUIRED int in query

    Responses:
        200: OK - ModelsListGameRecordKeysResponse (Retrieve list of records key by namespace)

        400: Bad Request - ModelsResponseError (18004: unable to retrieve list of key records)

        401: Unauthorized - ModelsResponseError (20001: unauthorized access)

        403: Forbidden - ModelsResponseError (20013: insufficient permission)

        500: Internal Server Error - ModelsResponseError (18001: unable to get record)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = ListGameRecordsHandlerV1.create(
        limit=limit,
        offset=offset,
        query=query,
        tags=tags,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )
